pub struct ArrangementEdgeUse {
pub edge: usize,
pub reversed: bool,
}Expand description
One use of a piece in a region boundary.
Fields
edge: usizeIndex into ArcArrangement::edges.
reversed: boolWhether the boundary traverses the piece from to to from.