Struct OrientedRectangle

pub struct OrientedRectangle {
    pub centre: Point2,
    pub axes: [Vec2; 2],
    pub half_extents: [f64; 2],
}
A rectangle by its centre, two unit axes and the half extents along them.

Fields

centre: Point2

Centre.

axes: [Vec2; 2]

Unit axes, counter-clockwise: the second is the first turned a quarter. The first points into [0, 90) degrees.

half_extents: [f64; 2]

Half the side lengths along the axes; one is zero for collinear input, both for a single point.

Implementations

Source

impl OrientedRectangle

pub fn area(&self) -> f64

Its area.

pub fn corners(&self) -> [Point2; 4]

The corners, counter-clockwise.