#[non_exhaustive]pub enum BoundSide {
Inner,
Outer,
}Expand description
Which side of the exact disc morphology a region lies on.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Inner
Contained in the exact result. A route found in an inner erosion proves reachability; “unreachable” proves nothing.
Outer
Containing the exact result. “Unreachable” in an outer erosion is a proof; a route found in it may be invalid.